# -*- coding: utf-8 -*-

NGINX = '''server {{
    listen [::]:{port} ssl http2;
    server_name {host}.{domain};

    access_log /var/log/nginx/{app}.access.log;
    error_log /var/log/nginx/{app}.error.log;

    location / {{
        proxy_pass http://{app}:8080;
    }}

    error_page 502 /502.html;
    location = /502.html {{
        root /usr/share/vmmgr/templates;
    }}

    location = /vm-ping {{
        add_header Content-Type text/plain;
        return 200 "vm-pong";
    }}
}}
'''

NGINX_DEFAULT = '''server {{
    listen [::]:80 default_server ipv6only=off;

    location / {{
        return 301 https://$host:{port}$request_uri;
    }}

    location /.well-known/acme-challenge/ {{
        root /etc/acme.sh.d;
    }}

    location = /vm-ping {{
        add_header Content-Type text/plain;
        return 200 "vm-pong";
    }}
}}

server {{
    listen [::]:{port} ssl http2 default_server ipv6only=off;

    location / {{
        proxy_pass http://127.0.0.1:8080;
    }}

    location /static {{
        root /usr/share/vmmgr;
    }}

    error_page 502 /502.html;
    location = /502.html {{
        root /usr/share/vmmgr/templates;
    }}

    location = /vm-ping {{
        add_header Content-Type text/plain;
        return 200 "vm-pong";
    }}
}}

server {{
    listen [::]:{port} ssl http2;
    server_name ~^(.*)\\.{domain_esc}$;

    location / {{
        return 503;
    }}

    location /static {{
        root /usr/share/vmmgr;
    }}

    error_page 503 /503.html;
    location = /503.html {{
        root /usr/share/vmmgr/templates;
    }}

    location = /vm-ping {{
        add_header Content-Type text/plain;
        return 200 "vm-pong";
    }}
}}
'''

ISSUE = '''
\x1b[1;32m   _____             _   _         __      ____  __ 
  / ____|           | | | |        \\ \\    / /  \\/  |
 | (___  _ __   ___ | |_| |_ ___ _ _\\ \\  / /| \\  / |
  \\___ \\| '_ \\ / _ \\| __| __/ _ \\ '__\\ \\/ / | |\\/| |
  ____) | |_) | (_) | |_| ||  __/ |   \\  /  | |  | |
 |_____/| .__/ \\___/ \\__|\\__\\___|_|    \\/   |_|  |_|
        | |                                         
        |_|\x1b[0m

 \x1b[1;33mUPOZORNĚNÍ:\x1b[0m Neoprávněný přístup k tomuto zařízení je zakázán.
 Musíte mít výslovné oprávnění k přístupu nebo konfiguraci tohoto zařízení.
 Neoprávněné pokusy a kroky k přístupu nebo používání tohoto systému mohou mít
 za následek občanské nebo trestní sankce.

 \x1b[1;33mCAUTION:\x1b[0m Unauthozired access to this device is prohibited.
 You must have explicit, authorized permission to access or configure this
 device. Unauthorized attempts and actions to access or use this system may
 result in civil or criminal penalties.

 Pro přístup k aplikacím otevřete jednu z těcho URL v internetovém prohlížeči.
 Open one the following URLs in web browser to access the applications.

   - \x1b[1m{url}\x1b[0m
   - \x1b[1m{ip}\x1b[0m\x1b[?1c
'''

LXC_CONTAINER = '''# Image name
lxc.uts.name = {name}

# Network
lxc.net.0.type = veth
lxc.net.0.link = lxcbr0
lxc.net.0.flags = up
lxc.net.0.ipv4.address = {ipv4}/16
lxc.net.0.ipv4.gateway = 172.17.0.1

# Volumes
lxc.rootfs.path = /var/lib/lxc/{name}/rootfs

# Mounts
lxc.mount.entry = shm dev/shm tmpfs rw,nodev,noexec,nosuid,relatime,mode=1777,create=dir 0 0
lxc.mount.entry = /etc/hosts etc/hosts none bind,create=file 0 0
lxc.mount.entry = /etc/resolv.conf etc/resolv.conf none bind,create=file 0 0
{mounts}

# Init
lxc.init.uid = {uid}
lxc.init.gid = {gid}
lxc.init.cwd = {cwd}

# Environment
lxc.environment = PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
{env}

# Halt
lxc.signal.halt = {halt}

# Log
lxc.console.size = 1MB
lxc.console.logfile = /var/log/lxc/{name}.log

# ID map
lxc.idmap = u 0 100000 65536
lxc.idmap = g 0 100000 65536

# Hooks
lxc.hook.pre-start = /usr/bin/vmmgr prepare-container {layers}
lxc.hook.post-stop = /usr/bin/vmmgr cleanup-container

# Other
lxc.arch = linux64
lxc.cap.drop = sys_admin
lxc.include = /usr/share/lxc/config/common.conf
lxc.include = /usr/share/lxc/config/userns.conf
'''
